@@ -57,10 +57,10 @@ def _findUsb():
 		try:
 			# find number of FTDI USB to serial devices attached
 			reg = _winreg.ConnectRegistry(None, _winreg.HKEY_LOCAL_MACHINE)
-			key = _winreg.CreateKey(reg, r"SYSTEM\CurrentControlSet\services\FTDIBUS\Enum")
+			key = _winreg.CreateKeyEx(reg, r"SYSTEM\CurrentControlSet\services\FTDIBUS\Enum", 0, _winreg.KEY_READ)
 			count = _winreg.QueryValueEx(key, "Count")[0]
 		except Exception as e:
-			logging.info("Could not find USB Buttonbox, no FTDI bus.\n")
+			logging.info("Could not find USB Buttonbox, no FTDI bus, \n{}".format(e))
 			return ""
 		
 		if count == 0:
@@ -96,24 +96,16 @@ def _findUsb():
 		# /sys/bus/usb/devices/
 		# /sys/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/serial
 		#s = os.popen('lsusb -d 0403:6001').read().rstrip()
-		#if s: # there is a usb device which appears to be our buttonbox
-			#now find the corresponding serial device
-			#logging.info("USB Buttonbox device found.")
-		
 		s = os.popen('ls -t /dev/serial/by-id/*FTDI*').read()
 		m = s.split()
 		if len(m)==0:
 			logging.info("Could not find USB Buttonbox")
-			#logging.warning("Could not match FTDI device")
 			return ""
 		if len(m) > 1:
 			logging.info("Multiple USB Buttonboxes connected, using the last connected.")
 		serial = m[0] # newest
 		logging.info("USB Buttonbox serial interface: "+serial)
 		return serial
-		#else:
-		#	logging.info("Could not find USB Buttonbox")
-		#	return ""
 			
 def clearEvents():
 	if bb == None:
@@ -187,6 +179,32 @@ def waitButtons(maxWait=float("inf"), buttonList=None, timeStamped=False):
 	else:
 		return c
 		
+def setLeds(leds=[False,False,False,False,False,False,False,False], val=None):
+	"""Set buttonbox LEDs to a certain pattern """
+	global bb
+	if bb == None:
+		logging.error("No buttonbox connected")
+		return 
+	if val == None:
+		val = 0
+		for i in range(8):
+			if len(leds)>i:
+				if leds[i]:
+					val += 1<<i
+			else:
+				break
+	bb.write(chr(val))
+	
+def waitLeds(leds=[False,False,False,False,False,False,False,False], wait=1.0, val=None):
+	"""Set buttonbox LEDs to a certain pattern and wait a while"""	
+	global bb
+	if bb == None:
+		logging.error("No buttonbox connected")
+		return 
+	setLeds(leds, val)
+	time.sleep(wait)
+	setLeds()
+
 # following line ensure that we see all the debugging and info output from the buttonbox
 logging.getLogger().setLevel(logging.DEBUG)
 __init__()
